==> qmapshack_1.16.1.orig.tar.gz: qmapshack-V_1.16.1/src/qmapshack/realtime/opensky/CRtOpenSkyInfo.h <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CRTOPENSKYINFO_H
#define CRTOPENSKYINFO_H

#include "realtime/IRtInfo.h"
#include "ui_IRtOpenSkyInfo.h"

#include <QPointer>

class CRtOpenSkyRecord;
class CRtOpenSky;
class CRtDraw;

class CRtOpenSkyInfo : public IRtInfo, private Ui::IRtOpenSkyInfo
{
    Q_OBJECT
public:
    CRtOpenSkyInfo(CRtOpenSky& source, QWidget* parent);
    virtual ~CRtOpenSkyInfo() = default;

    void loadSettings(QSettings& cfg);
    void saveSettings(QSettings& cfg) const;

public slots:
    void slotUpdate();

private:
    void startRecord(const QString& filename) override;
    void fillTrackData(CTrackData& data) override;
};

#endif //CRTOPENSKYINFO_H

==> qmapshack_1.18.1.orig.tar.gz: qmapshack-V_1.18.1/src/qmapshack/realtime/opensky/CRtOpenSkyInfo.h <==
/**********************************************************************************************
    Copyright (C) 2018 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CRTOPENSKYINFO_H
#define CRTOPENSKYINFO_H

#include <QPointer>

#include "realtime/IRtInfo.h"
#include "ui_IRtOpenSkyInfo.h"

class CRtOpenSkyRecord;
class CRtOpenSky;
class CRtDraw;

class CRtOpenSkyInfo : public IRtInfo, private Ui::IRtOpenSkyInfo {
  Q_OBJECT
 public:
  CRtOpenSkyInfo(CRtOpenSky& source, QWidget* parent);
  virtual ~CRtOpenSkyInfo() = default;

  void loadSettings(QSettings& cfg);
  void saveSettings(QSettings& cfg) const;

 public slots:
  void slotUpdate();

 private:
  void startRecord(const QString& filename) override;
  void fillTrackData(CTrackData& data) override;
};

#endif  // CRTOPENSKYINFO_H
